@@ -19,7 +19,7 @@ parser.add_argument('-b', '--bucket-name', action='store', help='override bucket
 # required=True
 subparsers = parser.add_subparsers(dest='action', metavar='action', help='action to run')
 images_parser = subparsers.add_parser('upload', help='upload files')
-images_parser.add_argument('-p', '--path', default=os.getcwd(), help='path to directory with images')
+images_parser.add_argument('-p', '--path', default=False, help='path to directory with images')
 images_parser.add_argument('-e', '--exclude', help='File extensions to exclude.', action='append', nargs='*')
 images_parser.add_argument('--dry', help='create upload file but dont actually upload anything', action='store_true')
 
@@ -28,6 +28,10 @@ logger = settings.get_logger()
 
 logger.info(f'Tasq CLI {settings.VERSION}')
 
+if not args.path:
+    logger.error('Path to upload is required.')
+    exit(1)
+
 # override client id if flag is present
 if args.client_id:
     settings.CLIENT_ID = args.client_id
